==> digikam-3.0.0-rc.tar.bz2: digikam-3.0.0-rc/extra/kipi-plugins/rawconverter/plugin/kipiplugin_rawconverter.desktop.cmake <==
[Desktop Entry]
Name=RawConverter
Name[ast]=RawConverter
Name[bg]=Конвертор за RAW
Name[ca]=RawConverter
Name[ca@valencia]=RawConverter
Name[cs]=RawConverter
Name[da]=RawConverter
Name[de]=Rohkonverter
Name[el]=RawConverter
Name[en_GB]=RawConverter
Name[es]=Conversor Raw
Name[et]=Toorpiltide teisendaja
Name[eu]=Raw bihurtzailea
Name[fi]=Raw-muunnin
Name[fr]=RawConverter
Name[ga]=RawConverter
Name[gl]=RawConverter
Name[he]=ממיר Raw
Name[hne]=रा-कनवर्टर
Name[hu]=Raw átalakító
Name[is]=RAWumbreytir
Name[it]=Convertitore raw
Name[ja]=RawConverter
Name[km]=កម្មវិធី​បម្លែង​ដើម
Name[ko]=RawConverter
Name[lv]=Raw pārveidotājs
Name[nb]=RAW-omformer
Name[nds]=RohWanneln
Name[nl]=RAW-convertor
Name[pa]=ਰਾਅ-ਕਨਵਰਟਰ
Name[pl]=PrzekształcanieRaw
Name[pt]=Conversão para RAW
Name[pt_BR]=Conversor RAW
Name[ro]=Copnvertor RAW
Name[ru]=Конвертор цифровых негативов (RAW)
Name[sk]=RAW konverzia
Name[sl]=RawConverter
Name[sq]=RawConverter
Name[sv]=Konvertering av obehandlade bilder
Name[th]=แปลงภาพแบบ Raw
Name[tr]=Ham Dönüştürücü
Name[uk]=RawConverter
Name[x-test]=xxRawConverterxx
Name[zh_CN]=Raw 转换器
Name[zh_TW]=Raw 轉換程式
Comment=A tool to convert Raw Image to JPEG/PNG/TIFF
Comment[ast]=Una ferramienta pa convertir imáxenes RAW en JPEG/PNG/TIFF
Comment[bg]=Инструмент за конвертиране (проявяване) на изображения от RAW към JPEG/PNG/TIFF
Comment[ca]=Una eina per a convertir imatges RAW a JPEG/PNG/TIFF
Comment[ca@valencia]=Una eina per a convertir imatges RAW a JPEG/PNG/TIFF
Comment[cs]=Nástroj pro převod RAW obrázků do JPEG/PNG/TIFF
Comment[da]=Et værktøj til at konvertere RAW-billeder til JPEG/PNG/TIFF
Comment[de]=Ein Werkzeug, um Kamerarohbilder nach JPEG/PNG/TIFF zu konvertieren.
Comment[el]=Εργαλείο για τη μετατροπή RAW εικόνων σε JPEG/PNG/TIFF
Comment[en_GB]=A tool to convert Raw Image to JPEG/PNG/TIFF
Comment[es]=Una herramienta para convertir imágenes RAW a JPEG/PNG/TIFF
Comment[et]=Tööriist toorpiltide teisendamiseks JPEG/PNG/TIFF-piltidkes
Comment[eu]=Irudi gordinak (Raw) JPEG/PNG/TIFF formatura bihurtzeko tresna
Comment[fr]=Outil de conversion d'image RAW en JPEG/PNG/TIFF
Comment[ga]=Uirlis a thiontaíonn íomhánna RAW go JPEG/PNG/TIFF
Comment[gl]=Unha ferramenta para converter imaxes Raw en JPEG/PNG/TIFF
Comment[he]=כלי להמרת תמונות Raw ל-JPEG/PNG/TIFF
Comment[hne]=रा फोटू ल जेपीईजी/पीएनजी/टिफ मं बदले के एक औजार
Comment[hu]=Egy eszköz Raw képek átalakításához JPEG/PNG/TIFF formátumba
Comment[is]=Verkfæri til að umbreyta RAW myndum í JPEG/PNG/TIFF
Comment[it]=Uno strumento per convertire immagini raw in JPEG, PNG o TIFF
Comment[ja]=RAW 画像を JPEG/PNG/TIFF に変換するツール
Comment[km]=ឧបករណ៍​ត្រូវ​បម្លែង​រូបភាព Raw ទៅ​ជា JPEG/PNG/TIFF
Comment[lv]=Rīks RAW attēlu pārveidošanai uz JPEG/PNG/TIFF
Comment[nb]=Et verktøy for å omforme RAW-bilder til JPEG/PNG/TIFF
Comment[nds]=En Warktüüch, mit dat sik Rohbiller na JPEG, PNG un TIFF wanneln laat
Comment[nl]=Een hulpmiddel om raw-afbeeldingen te converteren naar JPEG/PNG/TIFF
Comment[pa]=ਰਾਅ (Raw) ਚਿੱਤਰ ਨੂੰ JPEG/PNG/TIFF ਬਦਲਣ ਲਈ ਟੂਲ
Comment[pl]=Narzędzie do przekształcania obrazów Raw do JPEG/PNG/TIFF
Comment[pt]=Uma ferramenta de conversão em lote de imagens RAW em JPEG/PNG/TIFF
Comment[pt_BR]=Uma ferramenta para converter imagens RAW para JPEG/PNG/TIFF
Comment[ro]=O unealtă pentru convertirea imaginilor RAW în JPEG/PNG/TIFF
Comment[ru]=Инструмент для конвертирования цифровых негативов (RAW) в JPEG/PNG/TIFF
Comment[sk]=Nástroj na konverziu RAW obrázka do JPEG/PNG/TIFF
Comment[sl]=Orodje za pretvorbo grobih slik v JPEG/PNG/TIFF
Comment[sq]=Një mjet për të konvertuar imazhet Raw në JPEG/PNG/TIFF
Comment[sv]=Ett verktyg för att konvertera obehandlade bilder till JPEG, PNG eller TIFF
Comment[th]=เครื่องมือในการแปลงภาพแบบ Raw ไปเป็นภาพรูปแบบ JPEG/PNG/TIFF
Comment[tr]=Ham dosyaları  JPEG/PNG/TIFF biçimlerine dönüştürmek için bir araç
Comment[uk]=Інструмент для перетворення зображень цифрових негативів на JPEG/PNG/TIFF
Comment[x-test]=xxA tool to convert Raw Image to JPEG/PNG/TIFFxx
Comment[zh_CN]=一个转换 RAW 图像为 JPEG/PNG/TIFF 的工具
Comment[zh_TW]=將 Raw 影像轉換成 JPEG/PNG/TIFF 的工具
Type=Service
Icon=rawconverter
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_rawconverter
X-KIPI-PluginCategories=Batch,Tools
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
author=Gilles Caulier, caulier dot gilles at gmail dot com

==> digikam-4.4.0.tar.bz2: digikam-4.4.0/extra/kipi-plugins/rawconverter/plugin/kipiplugin_rawconverter.desktop.cmake <==
[Desktop Entry]
UntranslatedGenericName=RawConverter
Name=RawConverter
Name[ast]=RawConverter
Name[bg]=Конвертор за RAW
Name[bs]=Raw Konvertor
Name[ca]=RawConverter
Name[ca@valencia]=RawConverter
Name[cs]=RawConverter
Name[da]=RawConverter
Name[de]=Rohkonverter
Name[el]=RawConverter
Name[en_GB]=RawConverter
Name[es]=Conversor Raw
Name[et]=Toorpiltide teisendaja
Name[eu]=Raw bihurtzailea
Name[fi]=Raw-muunnin
Name[fr]=Outil de conversion de format brut
Name[ga]=RawConverter
Name[gl]=RawConverter
Name[he]=ממיר Raw
Name[hne]=रा-कनवर्टर
Name[hu]=Raw átalakító
Name[is]=RAWumbreytir
Name[it]=Convertitore raw
Name[ja]=RawConverter
Name[km]=កម្មវិធី​បម្លែង​ដើម
Name[ko]=RawConverter
Name[lv]=Raw pārveidotājs
Name[nb]=RAW-omformer
Name[nds]=RohWanneln
Name[nl]=RAW-convertor
Name[pa]=ਰਾਅ-ਕਨਵਰਟਰ
Name[pl]=PrzekształcanieRaw
Name[pt]=Conversão para RAW
Name[pt_BR]=Conversor RAW
Name[ro]=Copnvertor RAW
Name[ru]=Конвертор цифровых негативов (RAW)
Name[sk]=RAW konverzia
Name[sl]=RawConverter
Name[sq]=RawConverter
Name[sv]=Konvertering av obehandlade bilder
Name[th]=แปลงภาพแบบ Raw
Name[tr]=Ham Dönüştürücü
Name[uk]=RawConverter
Name[x-test]=xxRawConverterxx
Name[zh_CN]=Raw 转换器
Name[zh_TW]=Raw 轉換程式
Comment=A tool to convert Raw Image to JPEG/PNG/TIFF
Comment[ast]=Una ferramienta pa convertir imáxenes RAW en JPEG/PNG/TIFF
Comment[bg]=Инструмент за конвертиране (проявяване) на изображения от RAW към JPEG/PNG/TIFF
Comment[bs]=Alat za konvertovanje Raw slika u JPEG/PNG/TIFF
Comment[ca]=Una eina per a convertir imatges RAW a JPEG/PNG/TIFF
Comment[ca@valencia]=Una eina per a convertir imatges RAW a JPEG/PNG/TIFF
Comment[cs]=Nástroj pro převod RAW obrázků do JPEG/PNG/TIFF
Comment[da]=Et værktøj til at konvertere RAW-billeder til JPEG/PNG/TIFF
Comment[de]=Ein Werkzeug, um Kamerarohbilder nach JPEG/PNG/TIFF zu konvertieren.
Comment[el]=Εργαλείο για τη μετατροπή RAW εικόνων σε JPEG/PNG/TIFF
Comment[en_GB]=A tool to convert Raw Image to JPEG/PNG/TIFF
Comment[es]=Una herramienta para convertir imágenes RAW a JPEG/PNG/TIFF
Comment[et]=Tööriist toorpiltide teisendamiseks JPEG/PNG/TIFF-piltidkes
Comment[eu]=Irudi gordinak (Raw) JPEG/PNG/TIFF formatura bihurtzeko tresna
Comment[fr]=Outil de conversion d'images « RAW » en JPEG / PNG / TIFF
Comment[ga]=Uirlis a thiontaíonn íomhánna RAW go JPEG/PNG/TIFF
Comment[gl]=Unha ferramenta para converter imaxes Raw en JPEG/PNG/TIFF
Comment[he]=כלי להמרת תמונות Raw ל-JPEG/PNG/TIFF
Comment[hne]=रा फोटू ल जेपीईजी/पीएनजी/टिफ मं बदले के एक औजार
Comment[hu]=Egy eszköz Raw képek átalakításához JPEG/PNG/TIFF formátumba
Comment[is]=Verkfæri til að umbreyta RAW myndum í JPEG/PNG/TIFF
Comment[it]=Uno strumento per convertire immagini raw in JPEG, PNG o TIFF
Comment[ja]=RAW 画像を JPEG/PNG/TIFF に変換するツール
Comment[km]=ឧបករណ៍​ត្រូវ​បម្លែង​រូបភាព Raw ទៅ​ជា JPEG/PNG/TIFF
Comment[lv]=Rīks RAW attēlu pārveidošanai uz JPEG/PNG/TIFF
Comment[nb]=Et verktøy for å omforme RAW-bilder til JPEG/PNG/TIFF
Comment[nds]=En Warktüüch, mit dat sik Rohbiller na JPEG, PNG un TIFF wanneln laat
Comment[nl]=Een hulpmiddel om raw-afbeeldingen te converteren naar JPEG/PNG/TIFF
Comment[pa]=ਰਾਅ (Raw) ਚਿੱਤਰ ਨੂੰ JPEG/PNG/TIFF ਬਦਲਣ ਲਈ ਟੂਲ
Comment[pl]=Narzędzie do przekształcania obrazów Raw do JPEG/PNG/TIFF
Comment[pt]=Uma ferramenta de conversão em lote de imagens RAW em JPEG/PNG/TIFF
Comment[pt_BR]=Uma ferramenta para converter imagens RAW para JPEG/PNG/TIFF
Comment[ro]=O unealtă pentru convertirea imaginilor RAW în JPEG/PNG/TIFF
Comment[ru]=Инструмент для конвертирования цифровых негативов (RAW) в JPEG/PNG/TIFF
Comment[sk]=Nástroj na konverziu RAW obrázka do JPEG/PNG/TIFF
Comment[sl]=Orodje za pretvorbo grobih slik v JPEG/PNG/TIFF
Comment[sq]=Një mjet për të konvertuar imazhet Raw në JPEG/PNG/TIFF
Comment[sv]=Ett verktyg för att konvertera obehandlade bilder till JPEG, PNG eller TIFF
Comment[th]=เครื่องมือในการแปลงภาพแบบ Raw ไปเป็นภาพรูปแบบ JPEG/PNG/TIFF
Comment[tr]=Ham dosyaları  JPEG/PNG/TIFF biçimlerine dönüştürmek için bir araç
Comment[uk]=Інструмент для перетворення зображень цифрових негативів на JPEG/PNG/TIFF
Comment[x-test]=xxA tool to convert Raw Image to JPEG/PNG/TIFFxx
Comment[zh_CN]=一个转换 RAW 图像为 JPEG/PNG/TIFF 的工具
Comment[zh_TW]=將 Raw 影像轉換成 JPEG/PNG/TIFF 的工具
Type=Service
Icon=rawconverter
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_rawconverter
X-KIPI-PluginCategories=Batch,Tools
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
author=Gilles Caulier, caulier dot gilles at gmail dot com
